import requests
import random
import json
from hashlib import md5

class BaiduFanyi:
    def __init__(self, appid, appkey):
        self.appid = appid
        self.appkey = appkey
        endpoint = 'https://api.fanyi.baidu.com'
        path = '/api/trans/vip/translate'
        self.url = endpoint + path

    def _make_md5(self, s, encoding='utf-8'):
        return md5(s.encode(encoding)).hexdigest()

    def translate(self, text, fromLang="auto", toLang="zh"):
        query = text
        salt = random.randint(32768, 65536)
        sign = self._make_md5(self.appid + query
                              + str(salt) + self.appkey)

        headers = {'Content-Type': 'application/x-www-form-urlencoded'}
        payload = {'appid': self.appid, 'q': query, 'from': fromLang,
                   'to': toLang, 'salt': salt, 'sign': sign}

        r = requests.post(self.url, params=payload, headers=headers)
        result_json = json.loads(r.text)
        result_list = []
        for result in result_json["trans_result"]:
            result_list.append(result['dst'])
        return "\n".join(result_list)



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="baidufanyi",
    version="0.2.5",
    author="xuanzhi33",
    author_email="xuanzhi33@qq.com",
    url="https://github.com/xuanzhi33/baidufanyi",
    description="A simple SDK for the Baidu Translation API (unofficial)",
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    license="GPL-3.0",
    install_requires=["requests"],
    packages=find_packages(),
    python_requires=">=3.6"
)
